@@ -4,7 +4,7 @@
 /*       Cognitive Systems Group, University of Hamburg, Germany        */
 /*                                                                     */
 /*    This file is part of the VIGRA computer vision library.           */
-/*    ( Version 1.4.0, Dec 21 2005 )                                    */
+/*    ( Version 1.5.0, Dec 07 2006 )                                    */
 /*    The VIGRA Website is                                              */
 /*        http://kogs-www.informatik.uni-hamburg.de/~koethe/vigra/      */
 /*    Please direct questions, bug reports, and contributions to        */
@@ -198,7 +198,7 @@ struct TinyVectorTest
 
         shouldEqual(cross(bv3, bv3), IV(0));
         shouldEqual(cross(iv3, bv3), IV(0));
-        shouldEqual(cross(fv3, fv3), FV(0.0));
+        shouldEqualTolerance(cross(fv3, fv3), FV(0.0), FV(1e-6f));
 
         FV cr = cross(fv1, fv3);
         shouldEqualTolerance(cr[0], 1.2, 1e-6f);
@@ -332,7 +332,7 @@ struct RGBValueTest
         should(red(pf, 1) == 1.0);
         should(green(pf, 1) == 1.0);
         should(blue(pf, 1) == 1.0);
-        should(gray(pf, 1) == 1.0);
+        shouldEqualTolerance(gray(pf, 1), 1.0, 1e-6);
 
         rgb.setRed(1.0, pf);
         rgb.setGreen(2.0, pf);
